@@ -95,23 +95,23 @@ void ffPrintCPU(FFCPUOptions* options)
             FF_STRBUF_AUTO_DESTROY freqBase = ffStrbufCreate();
             ffParseFrequency(cpu.frequencyBase, &freqBase);
             FF_STRBUF_AUTO_DESTROY freqMax = ffStrbufCreate();
-            ffParseFrequency(cpu.frequencyBase, &freqMax);
+            ffParseFrequency(cpu.frequencyMax, &freqMax);
             FF_STRBUF_AUTO_DESTROY freqBioslimit = ffStrbufCreate();
             ffParseFrequency(cpu.frequencyBiosLimit, &freqBioslimit);
 
             FF_STRBUF_AUTO_DESTROY tempStr = ffStrbufCreate();
             ffTempsAppendNum(cpu.temperature, &tempStr, options->tempConfig, &options->moduleArgs);
             FF_PRINT_FORMAT_CHECKED(FF_CPU_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_CPU_NUM_FORMAT_ARGS, ((FFformatarg[]){
-                {FF_FORMAT_ARG_TYPE_STRBUF, &cpu.name, "name"},
-                {FF_FORMAT_ARG_TYPE_STRBUF, &cpu.vendor, "vendor"},
-                {FF_FORMAT_ARG_TYPE_UINT16, &cpu.coresPhysical, "cores-physical"},
-                {FF_FORMAT_ARG_TYPE_UINT16, &cpu.coresLogical, "cores-logical"},
-                {FF_FORMAT_ARG_TYPE_UINT16, &cpu.coresOnline, "cores-online"},
-                {FF_FORMAT_ARG_TYPE_STRBUF, &freqBase, "freq-base"},
-                {FF_FORMAT_ARG_TYPE_STRBUF, &freqMax, "freq-max"},
-                {FF_FORMAT_ARG_TYPE_STRBUF, &tempStr, "temperature"},
-                {FF_FORMAT_ARG_TYPE_STRBUF, &coreTypes, "core-types"},
-                {FF_FORMAT_ARG_TYPE_STRBUF, &freqBioslimit, "freq-bios-limit"},
+                FF_FORMAT_ARG(cpu.name, "name"),
+                FF_FORMAT_ARG(cpu.vendor, "vendor"),
+                FF_FORMAT_ARG(cpu.coresPhysical, "cores-physical"),
+                FF_FORMAT_ARG(cpu.coresLogical, "cores-logical"),
+                FF_FORMAT_ARG(cpu.coresOnline, "cores-online"),
+                FF_FORMAT_ARG(freqBase, "freq-base"),
+                FF_FORMAT_ARG(freqMax, "freq-max"),
+                FF_FORMAT_ARG(tempStr, "temperature"),
+                FF_FORMAT_ARG(coreTypes, "core-types"),
+                FF_FORMAT_ARG(freqBioslimit, "freq-bios-limit"),
             }));
         }
     }
