@@ -9,8 +9,16 @@ typedef enum FFDisplayCompactType
     FF_DISPLAY_COMPACT_TYPE_NONE = 0,
     FF_DISPLAY_COMPACT_TYPE_ORIGINAL_BIT = 1 << 0,
     FF_DISPLAY_COMPACT_TYPE_SCALED_BIT = 1 << 1,
+    FF_DISPLAY_COMPACT_TYPE_REFRESH_RATE_BIT = 1 << 2,
 } FFDisplayCompactType;
 
+typedef enum FFDisplayOrder
+{
+    FF_DISPLAY_ORDER_NONE,
+    FF_DISPLAY_ORDER_ASC,
+    FF_DISPLAY_ORDER_DESC,
+} FFDisplayOrder;
+
 typedef struct FFDisplayOptions
 {
     FFModuleBaseInfo moduleInfo;
@@ -18,4 +26,5 @@ typedef struct FFDisplayOptions
 
     FFDisplayCompactType compactType;
     bool preciseRefreshRate;
+    FFDisplayOrder order;
 } FFDisplayOptions;
